summaryrefslogtreecommitdiff
path: root/sw
diff options
context:
space:
mode:
authorJohnny_M <klasse@partyheld.de>2018-03-10 11:46:00 +0100
committerMichael Stahl <mstahl@redhat.com>2018-03-13 13:06:14 +0100
commitbba834eb9ae0df59bfe69f461fa625ade1d77f63 (patch)
tree674d1ecfe4322685ce2ea8cdde7e567b57cada66 /sw
parent83e5f4db3b42f5fce16dc1e0ce723a45329dab0f (diff)
Translate German variable names
Akt -> Current in wrtw8esh Change-Id: Ie2933ad59f9e01cfce57a5b3847048323be787c4 Reviewed-on: https://gerrit.libreoffice.org/51036 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Michael Stahl <mstahl@redhat.com>
Diffstat (limited to 'sw')
-rw-r--r--sw/source/filter/ww8/wrtw8esh.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/sw/source/filter/ww8/wrtw8esh.cxx b/sw/source/filter/ww8/wrtw8esh.cxx
index 92a310a69e0e..0471e0c73bff 100644
--- a/sw/source/filter/ww8/wrtw8esh.cxx
+++ b/sw/source/filter/ww8/wrtw8esh.cxx
@@ -1340,7 +1340,7 @@ void WW8Export::WriteOutliner(const OutlinerParaObject& rParaObj, sal_uInt8 nTyp
OSL_ENSURE( pO->empty(), " pO is not empty at start of line" );
OUString aStr( rEditObj.GetText( n ));
- sal_Int32 nAktPos = 0;
+ sal_Int32 nCurrentPos = 0;
const sal_Int32 nEnd = aStr.getLength();
const SfxItemSet aSet(rEditObj.GetParaAttribs(n));
@@ -1355,17 +1355,17 @@ void WW8Export::WriteOutliner(const OutlinerParaObject& rParaObj, sal_uInt8 nTyp
do {
const sal_Int32 nNextAttr = std::min(aAttrIter.WhereNext(), nEnd);
- bool bTextAtr = aAttrIter.IsTextAttr( nAktPos );
+ bool bTextAtr = aAttrIter.IsTextAttr( nCurrentPos );
if( !bTextAtr )
- OutSwString(aStr, nAktPos, nNextAttr - nAktPos);
+ OutSwString(aStr, nCurrentPos, nNextAttr - nCurrentPos);
// At the end of the line the attributes are extended over the CR.
// exception: foot note at line end
if( nNextAttr == nEnd && !bTextAtr )
WriteCR(); // CR after it
- // output of character attributes
- aAttrIter.OutAttr( nAktPos ); // nAktPos - 1 ??
+ // output of character attributes
+ aAttrIter.OutAttr( nCurrentPos ); // nCurrentPos - 1 ??
if (bIsRTLPara)
{
@@ -1384,10 +1384,10 @@ void WW8Export::WriteOutliner(const OutlinerParaObject& rParaObj, sal_uInt8 nTyp
// exception: foot note at line end
if( nNextAttr == nEnd && bTextAtr )
WriteCR(); // CR after it
- nAktPos = nNextAttr;
+ nCurrentPos = nNextAttr;
aAttrIter.NextPos();
}
- while( nAktPos < nEnd );
+ while( nCurrentPos < nEnd );
OSL_ENSURE( pO->empty(), " pO is not empty at start of line" );